package com.intellij.jpdm;

import com.intellij.jpdm.model.xml.JpdlNamedActivity;
import com.intellij.jpdm.model.xml.*;
import com.intellij.jpdm.resources.messages.JpdlBundle;
import com.intellij.openapi.components.ApplicationComponent;
import com.intellij.patterns.DomPatterns;
import com.intellij.psi.PsiElement;
import com.intellij.psi.xml.XmlTag;
import com.intellij.refactoring.rename.RenameInputValidator;
import com.intellij.refactoring.rename.RenameInputValidatorRegistry;
import com.intellij.util.ProcessingContext;
import com.intellij.util.xml.DomElement;
import com.intellij.util.xml.DomManager;
import com.intellij.util.xml.TypeNameManager;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;

/**
 * User: Sergey.Vasiliev
 */
public class JpdlApplicationComponent implements ApplicationComponent {

  @NonNls
  @NotNull
  public String getComponentName() {
    return getClass().getName();
  }

  public void initComponent() {
    registerPresentations();

    registerRenameValidators();
  }

  private static void registerPresentations() {
    TypeNameManager.registerTypeName(ProcessDefinition.class, JpdlBundle.message("jpdl.process"));
    TypeNameManager.registerTypeName(Start.class, JpdlBundle.message("jpdl.start"));
    TypeNameManager.registerTypeName(Decision.class, JpdlBundle.message("jpdl.decision"));
    TypeNameManager.registerTypeName(Task.class, JpdlBundle.message("jpdl.task"));
    TypeNameManager.registerTypeName(State.class, JpdlBundle.message("jpdl.state"));
    TypeNameManager.registerTypeName(SubProcess.class, JpdlBundle.message("jpdl.subprocess"));
    TypeNameManager.registerTypeName(End.class, JpdlBundle.message("jpdl.end"));
    TypeNameManager.registerTypeName(EndCancel.class, JpdlBundle.message("jpdl.end.cancel"));
    TypeNameManager.registerTypeName(EndError.class, JpdlBundle.message("jpdl.end.error"));
    TypeNameManager.registerTypeName(Fork.class, JpdlBundle.message("jpdl.fork"));
    TypeNameManager.registerTypeName(Join.class, JpdlBundle.message("jpdl.join"));
    TypeNameManager.registerTypeName(Rules.class, JpdlBundle.message("jpdl.rules"));
    TypeNameManager.registerTypeName(RulesDecision.class, JpdlBundle.message("jpdl.rules.decision"));
    TypeNameManager.registerTypeName(Script.class, JpdlBundle.message("jpdl.script"));
    TypeNameManager.registerTypeName(Sql.class, JpdlBundle.message("jpdl.sql"));
    TypeNameManager.registerTypeName(Hql.class, JpdlBundle.message("jpdl.hql"));
    TypeNameManager.registerTypeName(Custom.class, JpdlBundle.message("jpdl.custom"));
    TypeNameManager.registerTypeName(Mail.class, JpdlBundle.message("jpdl.mail"));
  }

  private static void registerRenameValidators() {
    RenameInputValidatorRegistry.getInstance()
      .registerInputValidator(DomPatterns.domTargetElement(DomPatterns.domElement(JpdlNamedActivity.class)), new RenameInputValidator() {
        public boolean isInputValid(final String newName, final PsiElement element, final ProcessingContext context) {
          return  !(newName.contains("\""));
        }
      });
  }

  public void disposeComponent() {
  }

}