package com.intellij.jpdm.fileEditor;

import com.intellij.ide.structureView.StructureViewBuilder;
import com.intellij.jpdm.resources.messages.JpdlBundle;
import com.intellij.openapi.graph.builder.util.GraphViewUtil;
import com.intellij.openapi.graph.view.Graph2DView;
import com.intellij.openapi.progress.ProgressManager;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.util.Disposer;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.psi.PsiFile;
import com.intellij.psi.xml.XmlFile;
import com.intellij.util.xml.DomElement;
import com.intellij.util.xml.ui.PerspectiveFileEditor;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import javax.swing.*;
import java.util.List;

public class JpdlDesignerFileEditor extends PerspectiveFileEditor {

    private JpdlDesignerComponent myComponent;
    private final XmlFile myXmlFile;

    public JpdlDesignerFileEditor(final Project project, final VirtualFile file) {
        super(project, file);

        final PsiFile psiFile = getPsiFile();
        assert psiFile instanceof XmlFile;

        myXmlFile = (XmlFile) psiFile;
    }


    @Nullable
    protected DomElement getSelectedDomElement() {
        final List<DomElement> selectedDomElements = getJpdlDesignerComponent().getSelectedDomElements();

        return selectedDomElements.size() > 0 ? selectedDomElements.get(0) : null;
    }

    protected void setSelectedDomElement(final DomElement domElement) {
        getJpdlDesignerComponent().setSelectedDomElement(domElement);
    }

    @NotNull
    protected JComponent createCustomComponent() {
        return getJpdlDesignerComponent();
    }

    @Nullable
    public JComponent getPreferredFocusedComponent() {
        return ((Graph2DView) getJpdlDesignerComponent().getBuilder().getGraph().getCurrentView()).getJComponent();
    }

    public void commit() {
    }

    public void reset() {
        getJpdlDesignerComponent().getBuilder().queueUpdate();
    }

    @NotNull
    public String getName() {
        return JpdlBundle.message("jpdl.file.editor.designer.name");
    }

    public StructureViewBuilder getStructureViewBuilder() {
        return GraphViewUtil.createStructureViewBuilder(getJpdlDesignerComponent().getOverview());
    }

    private JpdlDesignerComponent getJpdlDesignerComponent() {
        if (myComponent == null) {
            final JpdlDesignerComponent[] graphComponent = {null};
            ProgressManager.getInstance().runProcessWithProgressSynchronously(new Runnable() {
                public void run() {
                    graphComponent[0] = new JpdlDesignerComponent(myXmlFile);
                }
            }, JpdlBundle.message("progress.manager.generating.designer.component"), false, myXmlFile.getProject());


            myComponent = graphComponent[0];
            Disposer.register(this, myComponent);
        }
        return myComponent;
    }
}

