package com.intellij.jpdm.graph.nodes;

import com.intellij.jpdm.graph.JpdlNode;
import com.intellij.jpdm.model.xml.JpdlNamedActivity;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

/**
 * User: Sergey.Vasiliev
 */
public abstract class JpdlBasicNode<T extends JpdlNamedActivity> implements JpdlNode<T> {

    private final T myIdentifyingElement;
    private final String myName;

    protected JpdlBasicNode(@NotNull final T identifyingElement) {
        this(identifyingElement, identifyingElement.getName().getStringValue());

    }

    protected JpdlBasicNode(@NotNull final T identifyingElement, @Nullable final String name) {
        myIdentifyingElement = identifyingElement;
        myName = name == null ? "" : name;
    }

    public String getName() {
        return myName;
    }

    @NotNull
    public T getIdentifyingElement() {
        return myIdentifyingElement;
    }

    public boolean equals(final Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        final JpdlBasicNode that = (JpdlBasicNode) o;

        if (!myIdentifyingElement.equals(that.myIdentifyingElement)) return false;

        return true;
    }

    public int hashCode() {
        int result;
        result = myIdentifyingElement.hashCode();
        result = 31 * result + (myName != null ? myName.hashCode() : 0);
        return result;
    }
}
