package com.intellij.jpdm.model.xml.converters;

import com.intellij.jpdm.model.xml.ProcessDefinition;
import com.intellij.jpdm.utils.JpdlCommonUtils;
import com.intellij.openapi.module.Module;
import com.intellij.util.xml.ConvertContext;
import com.intellij.util.xml.ResolvingConverter;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Collection;
import java.util.List;

/**
 * User: Sergey.Vasiliev
 */
public class ProcessDefinitionConverter extends ResolvingConverter<ProcessDefinition> {

    @NotNull
    public Collection<ProcessDefinition> getVariants(final ConvertContext context) {
        return getProcessDefinitions(context);
    }

    public ProcessDefinition fromString(@Nullable @NonNls final String s, final ConvertContext context) {
        if (s == null) return null;

        final List<ProcessDefinition> processDefinitions = getProcessDefinitions(context);
        for (ProcessDefinition definition : processDefinitions) {
            if (s.equals(definition.getName().getStringValue())) {
                return definition;
            }
        }

        return null;
    }

    @NotNull
    private static List<ProcessDefinition> getProcessDefinitions(final ConvertContext context) {
        final Module module = context.getModule();

        return JpdlCommonUtils.getProcessDefinitions(module);
    }

    public String toString(@Nullable final ProcessDefinition processDefinition, final ConvertContext context) {
        return processDefinition == null ? null : processDefinition.getName().getStringValue();
    }
}

