/*
 * Copyright 2000-2009 JetBrains s.r.o.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.intellij.jpdm.providers;

import com.intellij.jpdm.JpdlIcons;
import com.intellij.jpdm.model.xml.JpdlDomElement;
import com.intellij.jpdm.model.xml.*;
import com.intellij.jpdm.model.xml.wireObjectGroup.JavaActivity;
import com.intellij.util.Icons;
import com.intellij.util.xml.DomElement;
import com.intellij.util.xml.DomIconProvider;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;

public class JpdlIconProvider extends DomIconProvider {

    public Icon getIcon(@NotNull DomElement element, int flags) {
        if (!(element instanceof JpdlDomElement)) {
            return null;
        }

        if (element instanceof State) {
            return JpdlIcons.STATE;
        } else if (element instanceof Decision) {
            return JpdlIcons.DECISION;
        } else if (element instanceof Start) {
            return JpdlIcons.START;
        } else if (element instanceof EndCancel) {
            return JpdlIcons.END_CANCEL;
        } else if (element instanceof EndError) {
            return JpdlIcons.END_ERROR;
        } else if (element instanceof SubProcess) {
            return JpdlIcons.SUB_PROCESS;
        } else if (element instanceof Task) {
            return JpdlIcons.TASK;
        } else if (element instanceof Join) {
            return JpdlIcons.JOIN;
        } else if (element instanceof Fork) {
            return JpdlIcons.FORK;
        } else if (element instanceof End) {
            return JpdlIcons.END;
        } else if (element instanceof JavaActivity) {
            return Icons.CLASS_ICON;
        } else if (element instanceof Script) {                         
            return JpdlIcons.SCRIPT;
        } else if (element instanceof Sql) {
            return JpdlIcons.SQL;
        } else if (element instanceof Hql) {
            return JpdlIcons.HQL;
        } else if (element instanceof Rules) {
            return JpdlIcons.RULES;
        } else if (element instanceof RulesDecision) {
            return JpdlIcons.RULES_DECISION;
        } else if (element instanceof Custom) {
            return JpdlIcons.CUSTOM;
        } else if (element instanceof Mail) {
            return JpdlIcons.MAIL;
        } else if (element instanceof ProcessDefinition) {
            return JpdlIcons.PROCESS;
        } else if (element instanceof Group) {
            return JpdlIcons.GROUP;
        }

        return null;
    }
}
