package com.intellij.jpdm.providers;

import com.intellij.jpdm.model.xml.ProcessDefinition;
import com.intellij.jpdm.utils.JpdlCommonUtils;
import com.intellij.openapi.module.Module;
import com.intellij.openapi.module.ModuleUtil;
import com.intellij.pom.references.PomService;
import com.intellij.psi.*;
import com.intellij.util.ProcessingContext;
import com.intellij.util.xml.DomTarget;
import org.jetbrains.annotations.NotNull;

import java.util.List;

/**
 * User: Sergey.Vasiliev
 */
public class ProcessNamesReferenceProvider extends PsiReferenceProvider {

    @NotNull
    public PsiReference[] getReferencesByElement(@NotNull PsiElement element, @NotNull final ProcessingContext context) {
        if (element instanceof PsiLiteralExpression) {
            final PsiLiteralExpression literalExpression = (PsiLiteralExpression) element;
            final Module module = ModuleUtil.findModuleForPsiElement(element);
            if (module != null && literalExpression.getValue() instanceof String) {
                return new PsiReference[]{new JpdlProcessPsiReference(literalExpression, module)};
            }
        }
        return PsiReference.EMPTY_ARRAY;
    }

    private static class JpdlProcessPsiReference extends PsiReferenceBase<PsiLiteralExpression> {
        private Module myModule;

        public JpdlProcessPsiReference(PsiLiteralExpression literalExpression, Module module) {
            super(literalExpression, false);
            myModule = module;
        }

        @Override
        public boolean isSoft() {
            return false;
        }

        public PsiElement resolve() {
            final String value = getValue();
            for (ProcessDefinition definition : JpdlCommonUtils.getProcessDefinitions(myModule)) {
                if (value.equals(definition.getName().getStringValue())) {
                    return PomService.convertToPsi(DomTarget.getTarget(definition));
                }
            }
            return null;
        }

        @NotNull
        public Object[] getVariants() {
            final List<String> names = JpdlCommonUtils.getProcessNames(myModule);

            return names.toArray(new Object[names.size()]);
        }
    }
}
