package com.intellij.jpdm.utils;

import com.intellij.jpdm.model.JpdlDomModelManager;
import com.intellij.jpdm.model.JpdlModel;
import com.intellij.jpdm.model.xml.ProcessDefinition;
import com.intellij.openapi.module.Module;
import com.intellij.util.Function;
import com.intellij.util.containers.ContainerUtil;
import org.apache.commons.collections.CollectionUtils;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Collections;
import java.util.List;

/**
 * User: Sergey.Vasiliev
 */
public class JpdlCommonUtils {

    @NotNull
    public static List<ProcessDefinition> getProcessDefinitions(@Nullable Module module) {
        if (module == null) return Collections.emptyList();

        final List<JpdlModel> models = JpdlDomModelManager.getInstance(module.getProject()).getAllModels(module);
        return ContainerUtil.map2List(models, new Function<JpdlModel, ProcessDefinition>() {
            public ProcessDefinition fun(final JpdlModel processModel) {
                return processModel.getRoots().get(0).getRootElement();
            }
        });
    }

    @NotNull
    public static List<String> getProcessNames(@Nullable Module module) {
        return ContainerUtil.mapNotNull(getProcessDefinitions(module), new Function<ProcessDefinition, String>() {
            public String fun(ProcessDefinition processDefinition) {
                return processDefinition.getName().getStringValue();
            }
        });


    }
}
